/************************************************************************
 * Copyright (c) 2010 by SAS Institute Inc., Cary, NC, USA.            	*
 *                                                                     	*
 * NAME:          bankfdn_post_init_etl                                	*
 *                                                                     	*
 * PURPOSE:       Called at the end of solution init after the SASAUTOS	*
 *                macro path has been set up. Performs any other       	*
 *                customer-specific initialization during startup.     	*
 *                This may include additional macro paths, libname     	*
 *                assignments, or global macro variable definitions.   	*	
 *                                                                     	*
 * USAGE:         %bankfdn_post_init_etl(VERSION=)                     	*
 *                                                                     	*
 * PARAMETERS:    VERSION     The product version number               	*
 *                            that was passed to solution init files   	*
 *                                                                     	*
 ***********************************************************************/

%macro bankfdn_post_init_etl(VERSION=6.1);

options lrecl = 1024;
%global bisdata_root biscode_root bisucmacros_root bislog_root bankfdn_config_dir dds_path ;
%global fm_db_eng  fm_authdomain fm_server_nm fm_server dds_db_eng bank_config_flg ;
%global fm_fact fm_bridge fm_dim fm_detail fm_facterr fm_scratch fm_dabtinput dds_authdomain dds_database;
%global bankfdn_migr_script_path ; 
%global ora_service_path;

%local tmp_dds_db_eng tmp_fm_db_eng tmp_m_bank_config_flg;

/*Some of the statements like database connections and database libnames should not be executed while running the SDW. 
  'Y' means it is executing while sdw config. Here, we are setting the flag value to 'N' for those steps which are to be executed post-SDW.*/
%if %symexist(m_sdw_config_flg) = 0 %then %do;
	%global m_sdw_config_flg ; 
	%let m_sdw_config_flg = N;
%end;

%bankfdn_get_swc_property(propertyName=bankfdnsrvc.dds.dbms.type,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=tmp_dds_db_eng);
%let dds_db_eng = %upcase(&tmp_dds_db_eng);

%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.dbms.type,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=tmp_fm_db_eng);
%let fm_db_eng = %upcase(&tmp_fm_db_eng);

%bankfdn_get_swc_property(propertyName=bankfdnsrvc.load.banking, q_rd_swc=&BANKFDN_SRVR_SWC., outvar=tmp_m_bank_config_flg);
%let tmp_m_bank_config_flg = %kupcase(&tmp_m_bank_config_flg);

%if &tmp_m_bank_config_flg =TRUE %then %do;
	%let bank_config_flg =Y;
%end;
%else %do;
	%let bank_config_flg =N;	
%end;
 

/*Common for Banking and Generic */
%if &fm_db_eng. ne SAS %then %do;
	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.authdomain,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_authdomain);	
	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.dbms.server.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_server_nm);
	%bankfdn_get_host_name(ServerName=&fm_server_nm., outvar=fm_server);
	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.scratch.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_scratch);
	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.dim.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_dim);
%end;



/****************************formats/infornats macro variable*********************************************/
%global FMTRK DTTMFMT DTFMT;

%let FMTRK=12.;
%let DTTMFMT=NLDATM21.;
%let DTFMT=NLDATE10.;
/******************************************************************************/


/*******************************************/
/* Path where the bisdata folder is kept. This value is expected to include the Data folder.*/
/* Edit this line for bisdata_root */
	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.data.root,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=bisdata_root);
	/*%let bisdata_root = C:\TestSetup\SASInstall\SASConfig\Lev1\AppData\SASBankingFoundation\5.1\data;*/

/* Path where the logs folder is kept. This value is expected to include the logs folder.*/
/* Edit this line for bislog_root */
/* logs directory will be created under the bankfdn_config_dir. There is a provision made that bisdata_root can be present at a different location.*/

	%bankfdn_get_swc_property(propertyName=bankfdnsrvc.config.dir,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=bankfdn_config_dir);
	%let bislog_root = &bankfdn_config_dir./AppData/&BANKFDN_CONFIG_FOLDER_NM/&BANKFDN_VERSION./logs;
	/*%let bislog_root = C:\TestSetup\SASInstall\SASConfig\Lev1\AppData\SASBankingFoundation\5.1\logs;*/

/* Path where the code for bankfdn is kept. This value is expected to include sasmisc folder under the bankfdn folder.*/
/* Edit this line for biscode_root */

	%if ((&SYSSCP eq WIN) or (&SYSSCP eq DNTHOST)) %then %do;
		%let biscode_root = %sysget(SASROOT)/&BANKFDN_PROGRAMS_FOLDER_NM./sasmisc;
		%let bisucmacros_root = %sysget(SASROOT)/&BANKFDN_PROGRAMS_FOLDER_NM./ucmacros;
		%let bankfdn_migr_script_path = %sysget(SASROOT)/&BANKFDN_PROGRAMS_FOLDER_NM./sasmisc/migration;	
	%end;
	%else %do;
		%let biscode_root = %sysget(SASROOT)/misc/&BANKFDN_PROGRAMS_FOLDER_NM.;
		%let bisucmacros_root = %sysget(SASROOT)/ucmacros/&BANKFDN_PROGRAMS_FOLDER_NM.;
		%let bankfdn_migr_script_path = %sysget(SASROOT)/misc/&BANKFDN_PROGRAMS_FOLDER_NM./migration;
	%end;
	/*%let biscode_root = C:\TestSetup\SASInstall\SAS\SASFoundation\9.2\&BANKFDN_PROGRAMS_FOLDER_NM.\sasmisc;*/


/* Path where the uncompiled macros for bankfdn are kept. This value is expected to include ucmacros folder under the bankfdn folder.*/
/* Edit this line for ucmacros path */
	/*%let bisucmacros_root = C:\TestSetup\SASInstall\SAS\SASFoundation\9.2\&BANKFDN_PROGRAMS_FOLDER_NM.\ucmacros;*/



/* All Common Library specifications */
	libname control BASE "&bisdata_root./control"; /* i18nOK:Line */
	libname custpara BASE "&bisdata_root./param" ; /* i18nOK:Line */
	libname format "&bisdata_root./format"; /* i18nOK:Line */
	libname smd_ds "&bisdata_root./internationalization/en"; /* i18nOK:Line */
	libname bnk_func  "&bisdata_root./functions"; /* i18nOK:Line */

%if(%sysfunc(exist(custpara.parameter))) %then %do;	   
	%bankfdn_load_global_parameters(where=);
%end;	

%if %symexist(dds_exist_flag) = 0 %then %do;
	%let dds_exist_flag = 0;
%end;

%bankfdn_apdm_connect_param_dclr;
%bankfdn_dbctrl_connect_param;

/* Filerefs for deployed jobs */
	filename jobs "&bankfdn_config_dir./Applications/&BANKFDN_APPLICATION_FOLDER_NM./deployed_jobs/foundationmart"; /* i18nOK:Line */

/* Filerefs for format needed for Foundation mart */
	filename  ten_fmt "&bisdata_root./format/cust_tr.sas" ; /* i18nOK:Line */
	filename  age_fmt "&bisdata_root./format/cust_age.sas" ; /* i18nOK:Line */
	filename  dlq_fmt "&bisdata_root./format/cust_dlq.sas"; /* i18nOK:Line */


/* Assigning folders for format searching and compilation of macros */
options fmtsearch=(format work) MAUTOSOURCE ;

/*%include "&biscode_root./controlscripts/bankfdn_customize_para.sas"; */

/*Currently the following line is kept as commented. However this might be needed for internationalization*/
	/*%locale_specific_format;*/

/* Assigning  library options to be used for functions */
	%if %sysfunc(exist(bnk_func.funcs)) %then %do;
		options append=(cmplib=(bnk_func.funcs)); 
	%end;




%if ((&SYSSCP eq WIN) or (&SYSSCP eq DNTHOST)) %then %do;
	%let bisddl_root = %sysget(SASROOT)/&BANKFDN_PROGRAMS_FOLDER_NM./sasmisc/ddl;
%end;
%else %do;
	%let bisddl_root = %sysget(SASROOT)/misc/&BANKFDN_PROGRAMS_FOLDER_NM./ddl;
%end;

%let fm_db_eng_lowcase = %lowcase(&fm_db_eng.);

filename indexjb "&bisddl_root./&fm_db_eng_lowcase./indexscripts"; /* i18nOK:Line */
filename ddl "&bisddl_root./&fm_db_eng_lowcase."; /* i18nOK:Line */ 



/* Following configuration is only for both generic cs and csb */ 
	%if &fm_db_eng.=SAS %then %do;
		/* Dim and dbscr is the only library that is assigned both in Generic CS as well as Banking configuration */
		libname dbscr BASE "&bisdata_root./scratch/foundation_mart" ; /* i18nOK:Line */
		libname dim BASE "&bisdata_root./dim" ; /* i18nOK:Line */
	%end;
	
	%else %do;
		/* Library specifications for Bankfdn For non-SAS */
		%if &fm_db_eng.=TERADATA %then %do;
			%if %sysfunc(exist(bnk_func.mapping_udf_func_gt,DATA)) %then %do;
				OPTIONS SQL_FUNCTIONS=(TERADATA EXTERNAL_APPEND=bnk_func.mapping_udf_func_gt) ;
			%end;
			
			%if &m_sdw_config_flg = N %then %do;
				/* Dim and dbscr is the only library that is assigned both in Generic CS as well as Banking configuration */
				libname dbscr teradata  schema=&fm_scratch. server="&fm_server." authdomain=&fm_authdomain. ;
				libname dim teradata schema=&fm_dim. server="&fm_server." authdomain=&fm_authdomain. ;
			%end;
			
			
		%end;
		
		%if &fm_db_eng.=ORACLE %then %do;
			%if %sysfunc(exist(bnk_func.mapping_udf_func_gt,DATA)) %then %do;
				OPTIONS SQL_FUNCTIONS=(ORACLE EXTERNAL_APPEND=bnk_func.mapping_udf_func_gt) ;
			%end;
			
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.dbms.ora.service,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=ora_service_path);
			
			%if &m_sdw_config_flg = N %then %do;
				libname dbscr oracle path=&ora_service_path schema=&fm_scratch. authdomain=&fm_authdomain. ;
				libname dim oracle path=&ora_service_path schema=&fm_dim. authdomain=&fm_authdomain. ;				
			%end;
		%end;
	%end;

/* Following configuration is only for banking */ 
	%if &bank_config_flg.=Y %then %do;

		libname martscr BASE "&bisdata_root./scratch/foundation_mart"; /* i18nOK:Line */
		libname dimref BASE "&bisdata_root./dim/dimref" ; /* i18nOK:Line */

		/* Library specifications for Bankfdn For SAS */
		%if &fm_db_eng.=SAS %then %do;
			libname detail BASE "&bisdata_root./detail" ; /* i18nOK:Line */
			libname bridge BASE "&bisdata_root./bridge" ; /* i18nOK:Line */
			libname fact BASE "&bisdata_root./fact" ; /* i18nOK:Line */
			libname facterr BASE "&bisdata_root./error" ; /* i18nOK:Line */
			libname inpbase "&bisdata_root./abt_base_tables"; /* i18nOK:Line */
		%end;
		%else %do;
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.facts.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_fact);
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.details.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_detail);
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.bridge.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_bridge);
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.facterr.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_facterr);
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.mart.dabtinput.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=fm_dabtinput);
		
			%if &m_sdw_config_flg = N %then %do;
				/* Library specifications for Bankfdn For Teradata */
				%if &fm_db_eng.=TERADATA %then %do;
					libname detail teradata schema=&fm_detail. server="&fm_server." authdomain=&fm_authdomain. ;
					libname bridge teradata schema=&fm_bridge. server="&fm_server." authdomain=&fm_authdomain. ;
					libname fact teradata schema=&fm_fact. server="&fm_server." authdomain=&fm_authdomain. ;
					libname facterr teradata schema=&fm_facterr. server=&fm_server. authdomain=&fm_authdomain. ;
					libname inpbase teradata schema=&fm_dabtinput. server="&fm_server." authdomain=&fm_authdomain. ;
				%end;
				%else %if &fm_db_eng.=ORACLE %then %do;
					libname detail oracle schema=&fm_detail. path="&ora_service_path"  authdomain=&fm_authdomain. ;
					libname bridge oracle schema=&fm_bridge. path="&ora_service_path" authdomain=&fm_authdomain. ;
					libname fact oracle schema=&fm_fact. path="&ora_service_path"  authdomain=&fm_authdomain. ;
					libname facterr oracle schema=&fm_facterr. path="&ora_service_path" authdomain=&fm_authdomain. ;
					libname inpbase oracle schema=&fm_dabtinput. path="&ora_service_path" authdomain=&fm_authdomain. ;
				%end;
			%end;
		%end;

		/* Filerefs for deployed jobs */

		filename jobs "&bankfdn_config_dir./Applications/&BANKFDN_APPLICATION_FOLDER_NM./deployed_jobs/foundationmart"; /* i18nOK:Line */

		/* Filerefs for format needed for Foundation mart */

		filename  ten_fmt "&bisdata_root./format/cust_tr.sas" ; /* i18nOK:Line */
		filename  age_fmt "&bisdata_root./format/cust_age.sas" ; /* i18nOK:Line */
		filename  dlq_fmt "&bisdata_root./format/cust_dlq.sas"; /* i18nOK:Line */
	
	
		/* For Detail Data store for banking solutions Library */
		/* Path where the DDS library is kept.This value is expected to include the DDS folder. */
		%if &m_sdw_config_flg = N and &dds_exist_flag = 1 %then %do;
	
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.dds.authdomain,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=dds_authdomain);
			%bankfdn_get_swc_property(propertyName=bankfdnsrvc.dds.schema.name,q_rd_swc=&BANKFDN_SRVR_SWC.,outvar=dds_database);

			%if &dds_db_eng.= ORACLE %then %do;

				%local ora_service;
				%bankfdn_get_oracle_service_name(libref = dds,ServiceVarName = ora_service);

				libname dds oracle schema=&dds_database. path="&ora_service." authdomain=&dds_authdomain. ;
			%end;
			%else %if &dds_db_eng.= TERADATA %then %do;

				%if &fm_db_eng.= TERADATA %then %do; /*For DDS and FM in Teradata : In Databse processing */
					libname dds teradata  schema=&dds_database. server="&fm_server." authdomain=&fm_authdomain. ;
				%end;
				%else %do; /*Only DDS in teradata and FM on SAS */
					libname dds teradata  schema=&dds_database. server="&fm_server." authdomain=&dds_authdomain. ;
				%end;	

			%end;
			%else %do; /* Default engine for DDS : SAS */
				%bankfdn_get_library_path(libraryName=DDS,outvar=dds_path);
				libname dds "&dds_path."; 
			%end;
		%end;
		

	%end;/* configuration is only for banking */ 


%mend bankfdn_post_init_etl;
